package org.gnu.composer.CommonTools;

/**
 * This enum contains all the possible types of message
 * that can be logged. This is to be used in conjunction
 * with the Logger.
 * 
 * @author Branden Archer
 */
public class LogTypes 
{
	private int value_;
	private String name_;
	private LogTypes(int value, String name)
	{
		value_ = value;
		name_  = name;
	}
	
	public int value()
	{
		return value_;
	}
	
	public String toString()
	{
		return name_;
	}
	
	//**The following log types are for special situations, not standard
	//**message
	
	//When code debug information is wanted
	public static final int DEBUG_VALUE = 1;
	public static final LogTypes DEBUG = new LogTypes(DEBUG_VALUE,"DEBUG");
	
	//Strange events have occured, but they are recoverable
	public static final int WARNING_VALUE = 2;
	public static final LogTypes WARNING = new LogTypes(WARNING_VALUE,"WARNING");
	
	//Problems have occured and bad things are resulting
	public static final int ERROR_VALUE = 3;
	public static final LogTypes ERROR = new LogTypes(ERROR_VALUE,"ERROR");
	
	//Components of the system have failed and quit working
	public static final int CRASH_VALUE = 4;
	public static final LogTypes CRASH = new LogTypes(CRASH_VALUE,"CRASH");
	
	//A condition has occured which only means that a bug has been found.
	public static final int BUG_VALUE = 5;
	public static final LogTypes BUG = new LogTypes(BUG_VALUE,"BUG");
	
	//**The following log types are for standard status message from the different
	//system components
	
	//All messages sent to the Firmware or controling the drives will log on this
	public static final int FIRMWARE_VALUE = 6;
	public static final LogTypes FIRMWARE = new LogTypes(FIRMWARE_VALUE,"FIRMWARE");
	
	//All messages involving the burning engine will log to this
	public static final int ENGINE_VALUE = 7;
	public static final LogTypes ENGINE = new LogTypes(ENGINE_VALUE,"ENGINE");
	
	//All messages involving the db will log to this
	public static final int DB_VALUE = 8;
	public static final LogTypes DB = new LogTypes(DB_VALUE,"DB");
	
	//All messages involving ripping discs will log to this
	public static final int RIPPER_VALUE = 9;
	public static final LogTypes RIPPER = new LogTypes(RIPPER_VALUE,"RIPPER");
	
	//All messages involvidng the user interface will log to this
	public static final int GUI_VALUE = 10;
	public static final LogTypes GUI = new LogTypes(GUI_VALUE,"GUI");
	
	//All messages involving modifying or accessing the Linux OS will log to this.
	public static final int SYSTEM_VALUE = 11;
	public static final LogTypes SYSYEM = new LogTypes(SYSTEM_VALUE,"SYSTEM");
	
	public static final int STATUS_VALUE = 12;
	public static final LogTypes STATUS = new LogTypes(STATUS_VALUE,"STATUS");
}
