
package org.gnu.composer.CommonTools;

public class Nap
{

	/**
	 * Wraps the thread sleep call including the 
	 * try/catch block
	 * @param timeInMillisecs
	 */
	public static void rest(long timeInMillisecs)
	{
		try 
		{
			Thread.sleep(timeInMillisecs);
		}
		catch (InterruptedException e)
		{
			// Waking up from the Nap early is okay
			// just don't want to cause an error by
			// letting it slip past.
		}
	}
	
	/**
	 * Sleeps for a period of time in a synchronized
	 * wait on the calling thread
	 * @param timeInMillisecs
	 */
	public static void waitRest(long timeInMillisecs)
	{
		try
		{
			synchronized(Thread.currentThread())
			{
				Thread.currentThread().wait(timeInMillisecs);
			}
		}
		catch(InterruptedException e)
		{
			// Waking up from the Nap early is okay
			// just don't want to cause an error by
			// letting it slip past.
		}
	}
	
	/**
	 * Wakes up a given thread that is sleeping with
	 * a Thread.wait or a RaptorNap.waitRest call.
	 * @param threadToWake - thread to wake up.
	 */
	public static void wakeUp(Thread threadToWake)
	{
		synchronized(threadToWake)
		{
			threadToWake.notify();
		}
	}
}
