package org.gnu.composer.DB;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.Statement;
import java.util.Properties;

/**
 * Class that contains a main program which will
 * convert a blank db into a db usable by the
 * composer.
 * 
 * @author Branden Archer
 */
public class SetupDB 
{
	//Load up the driver class
	static
	{
		try
		{
			Class.forName("org.postgresql.Driver");
		}
		catch(Exception e)
		{
			e.printStackTrace();
			System.exit(1);
		}
	}
	
	/**
	 * Program that setups the tables in the db.
	 * @param args
	 */
	public static void main(String [] args)
	{
		int returnValue = 0;
		
		try
		{
			String url = DBConsts.DB_URL;
			Properties props = new Properties();
			props.setProperty("user",DBConsts.USERNAME);
			props.setProperty("password",DBConsts.PASSWORD);
			Connection conn = DriverManager.getConnection(url, props);
			
			//Create the active job table
			System.out.println("> Creating active job table");
			Statement statement = conn.createStatement();
			statement.execute(
				"create table " + DBConsts.ACTIVE_JOB_TABLE + " (" +
				DBConsts.ACTIVE_JOB_JOBID        + " int,"         +
				DBConsts.ACTIVE_JOB_STATE        + " int,"         +
				DBConsts.ACTIVE_JOB_TOTAL_DISCS  + " int,"         + 
				DBConsts.ACTIVE_JOB_DONE_DISCS   + " int,"         +
				DBConsts.ACTIVE_JOB_ERROR_DISCS  + " int,"         + 
				DBConsts.ACTIVE_JOB_LABEL        + " varchar(256)" + 
				");");
			
			//Create the backup table
			System.out.println("> Creating backups table");
			statement.execute(
				"create table " + DBConsts.BACKUP_TABLE + " (" +
				DBConsts.BACKUP_BACKUP_ID     + " int,"            + 
				DBConsts.BACKUP_NAME          + " varchar(256),"   + 
				DBConsts.BACKUP_DISC_SIZE     + " int,"   +
				DBConsts.BACKUP_CREATION_DATE + " timestamp, "     +
				DBConsts.BACKUP_NEW           + " bool"            +
 				");");
			
			//Create the config table
			System.out.println("> Creating config table");
			statement.execute(
				"create table " + DBConsts.CONFIG_TABLE + " (" + 
				DBConsts.CONFIG_NAME  + " varchar(50)," + 
				DBConsts.CONFIG_VALUE + " varchar(50)"  + 
				");");
			
			//Load in initial configurations.
			System.out.println("> Populating config table");
			statement.execute(
				"insert into " + DBConsts.CONFIG_TABLE + 
				"(" + DBConsts.CONFIG_NAME + "," + DBConsts.CONFIG_VALUE + ")" + 
				" values (" + 
				"'" + DBConsts.CONFIG_NEXT_BACKUPID + "','0'" + 
				");");
			statement.execute(
				"insert into " + DBConsts.CONFIG_TABLE + 
				"(" + DBConsts.CONFIG_NAME + "," + DBConsts.CONFIG_VALUE + ")" + 
				" values (" + 
				"'" + DBConsts.CONFIG_NEXT_JOBID + "','0'" + 
				");");
			
			System.out.println("> Database Created");
		}
		catch(Exception e)
		{
			e.printStackTrace();
			returnValue = 1;
		}
		
		
		System.exit(returnValue);
	}
}
