package org.gnu.composer.PrinterAccess;

public class ByteMath 
{
	/**
	 * Converts a byte into the equivalent integer.
	 * This method assumes that the byte is intended
	 * to be unsigned. 
	 * @param value - value to convert
	 * @return The equilvalent value of the byte
	 * if it were unsigned.
	 */
	public static int convByteToInt(byte value)
	{
		//If the value was negative for a byte, then nop out
		//the top '1111...' bytes that were appended.
		int intValue = value & 0xFF;
		return intValue;
	}
	
	/**
	 * Calculates a checksum of a byte array from given
	 * beginning and end points
	 * @param array - array to be used in the calculation
	 * @param startIndex - First index in the array to include
	 * @param endIndex - last index in the array to include
	 * @return checksum for the given parameters
	 */
	public static int calcChecksum(byte [] array, int startIndex, int endIndex)
	{
		int checksum = 0;
		
		for(int index = startIndex; index <= endIndex; index++)
		{
			checksum += convByteToInt(array[index]);
		}
		
		return checksum;
	}
	
	/**
	 * Calculate a check for a byte array
	 * @param array - array to be used in calculation
	 * @return checksum of all values in the array
	 */
	public static int calcChecksum(byte [] array)
	{
		return calcChecksum(array,0,array.length - 1);
	}
}
