package org.gnu.composer.CommonToolsTest;

import org.gnu.composer.Tester.Tester;
import org.gnu.composer.CommonTools.*;
import org.gnu.composer.RuntimeSettings.*;

public class CommonToolsTest extends Tester
{
	public static void main(String [] args)
	{
		printTestInfo(
			"CommonToolsTest",
			"Tests the different common tools for proper functionality");
		
		testRunCommand();
		testStartCommand();
		
		testPassed(true);
	}
	
	/**
	 * Tests that a command which is run returns the correct return value
	 */
	public static void testRunCommand()
	{
		boolean success = true;
		
		printStepInfo(
			"testRunCommand",
			"Tests that a command which is run returns the correct return value");
		
		for(int index = 0; index < 100; index++)
		{
			try
			{
				int returned = Command.runCommand(
					RuntimeSettings.buildRoot + "org/gnu/composer/CommonToolsTest/RunCommandTest " + index);
				if(returned != index)
				{
					System.out.println("Expected return code " + index + " but got " + returned);
					success = false;
				}
			}
			catch(Exception e)
			{
				e.printStackTrace();
				System.out.println("Could not execute program for index " + index);
				success = false;
			}
		}
		
		stepPassed(success);
	}
	
	/**
	 * Tests that a command which is started spits out the expected string
	 */
	public static void testStartCommand()
	{
		boolean success = true;
		
		printStepInfo(
			"testStartCommand",
			"Tests that a command which is started spits out the expected string");
		
		for(int index = 0; index < 100; index++)
		{
			try
			{
				CommandLine program = Command.startCommand(
					RuntimeSettings.buildRoot + "org/gnu/composer/CommonToolsTest/RunCommandTest " + index);
				
				String expected = "Return Code: " + index;
				String actual = program.programStdout.readLine();
				
				if(expected.equals(actual) == false)
				{
					System.out.println("Expected \"" + expected + "\" but got \"" + actual + "\"");
					success = false;
				}
				
				int returned = Command.waitUntilCommandEnds(program);
				
				if(returned != index)
				{
					System.out.println("Expected return code " + index + " but got " + returned);
					success = false;
				}
			}
			catch(Exception e)
			{
				System.out.println("Could not execute program for index " + index);
				success = false;
			}
		}
		
		stepPassed(success);
	}
}
