package org.gnu.composer.PrinterAccessTest;

import org.gnu.composer.CommonTools.Command;
import org.gnu.composer.PrinterAccess.ByteMath;
import org.gnu.composer.RuntimeSettings.RuntimeSettings;
import org.gnu.composer.Tester.Tester;

public class PrinterAccessTest extends Tester
{
	public static void main(String [] args)
	{
		printTestInfo(
			"PrinterAccessTest",
			"Tests the different printer access tools work correctly");
		
		testConvByteToInt();
		testCalcChecksum();
		
		testPassed(true);
	}
	
	/**
	 * Tests that can properly convert a byte to an int
	 */
	public static void testConvByteToInt()
	{
		boolean success = true;
		
		printStepInfo(
			"testConvByteToInt",
			"Tests that can properly convert a byte to an int");
		
		for(int index = 0; index <= 255; index++)
		{
			int returned = ByteMath.convByteToInt((byte)(0xFF & index));
			if(index != returned)
			{
				System.out.println("Could not convert " + index + ", got " + returned);
				success = false;
			}
		}
		
		stepPassed(success);
	}
	
	/**
	 * Tests that can properly calculate a checksum from bytes
	 */
	public static void testCalcChecksum()
	{
		boolean success = true;
		
		printStepInfo(
			"testCalcChecksum",
			"Tests that can properly calculate a checksum from bytes");
		
		//Try a checksum will all possible byte values
		for(int index = 0; index <= 255; index++)
		{
			byte [] array = new byte[index];
			int expectedChecksum = 0;
			for(int innerIndex = 0; innerIndex < index; innerIndex++)
			{
				expectedChecksum += index;
				array[innerIndex] = (byte)index;
			}
			
			int actualChecksum = ByteMath.calcChecksum(array);
			
			if(expectedChecksum != actualChecksum)
			{
				System.out.println("Expected checksum " + expectedChecksum + " but got " + actualChecksum);
				success = false;
			}
		}
		
		stepPassed(success);
	}
}
