package org.gnu.composer.Tester;

/**
 * This class contains methods which
 * will be helpful when creating a class
 * which tests a part of the system. This
 * class should be extended, not simply
 * used, for the maximum benefit.
 * 
 * @author Branden Archer
 */
public class Tester 
{
	/**
	 * Print out a header for the test
	 * @param classname
	 * @param testDescription
	 */
	public static final void printTestInfo(String classname, String testDescription)
	{
		System.out.println(
			"======================================\n"
			+ "Test: " + classname + "\n"
			+ "Description: " + testDescription);
	}
	
	/**
	 * Prints out a header for a step in a test
	 * @param stepname
	 * @param stepDescription
	 */
	public static final void printStepInfo(String stepname, String stepDescription)
	{
		System.out.println(
			"--------------------------------------\n"
			+ "Step: " + stepname + "\n"
			+ "Description: " + stepDescription);
	}
	
	/**
	 * Prints out a footer for a step, saying it is passed or failed.
	 * If it failed, the test fails and stops executing.
	 * @param passed
	 */
	public static final void stepPassed(boolean passed)
	{
		if(passed)
		{
			System.out.println("Step: Pass\n" + "--------------------------------------");
		}
		else
		{
			System.out.println("Step: Fail\n" + "--------------------------------------");
			testPassed(false);
		}
	}
	
	/**
	 * conveince method for printing information during
	 * the test
	 * @param message
	 */
	public static final void info(String message)
	{
		System.out.println("> " + message);
	}
	
	/**
	 * Conveince method for printing an error during
	 * the test.
	 * @param message
	 */
	public static final void error(String message)
	{
		System.out.println("  ** " + message);
	}
	
	private static final int PASS = 0;
	private static final int FAIL = 1;
	
	/**
	 * Return to make that the test passed.
	 */
	private static final void testPassed()
	{
		System.exit(PASS);
	}
	
	/**
	 * Return to make that the test failed.
	 */
	private static final void testFailed()
	{
		System.exit(FAIL);
	}
	
	/**
	 * At the end of a test, call this method with
	 * a flag saying if the test passed or failed.
	 * This message will be relayed to make, which will
	 * halt the buid if a test failed.
	 * 
	 * @param passed - True iff the test passed.
	 */
	public static final void testPassed(boolean passed)
	{
		if(passed)
		{
			System.out.println("Test: Pass\n" 
				+ "======================================");
			testPassed();
		}
		else
		{
			System.out.println("Test: Fail\n" 
					+ "======================================");
			testFailed();
		}
	}
}
